@@ -18,9 +18,11 @@
 # along with pyrocumulus.  If not, see <http://www.gnu.org/licenses/>.
 
 
+import os
 import sys
 import argparse
 import importlib
+from pkg_resources import resource_filename
 from pyrocumulus.exceptions import(PyrocumulusCommandNotFound,
                                    PyrocumulusException)
 
@@ -49,8 +51,8 @@ class BaseCommand:
 
     description = None
     # --settings=settings.module
-    default_options = [{'args': ('--settings=',),
-                        'kwargs': {'default': 'settings',
+    default_options = [{'args': ('--settings',),
+                        'kwargs': {'default': None,
                                    'help': 'settings module to use',
                                    'nargs': '?'}}]
     user_options = []
@@ -60,6 +62,10 @@ class BaseCommand:
         self.parser = argparse.ArgumentParser()
         self.add_args()
         self.parse_args()
+        self.setenv()
+
+    def __call__(self):
+        return self.run()
 
     def add_args(self):
         """
@@ -79,6 +85,7 @@ class BaseCommand:
         Parse the args from the command line
         """
         options = self.parser.parse_args()
+        self.settings = None
         args = [opt for opt in dir(options) if not opt.startswith('_')]
         for arg in args:
             setattr(self, arg, getattr(options, arg))
@@ -93,6 +100,14 @@ class BaseCommand:
         name = self.__class__.__module__.split('.')[-1]
         return name
 
+    def setenv(self):
+        """
+        Set the env variable PYROCUMULUS_SETTINGS_MODULE
+        using the value passed on --setting option
+        """
+        if self.settings:
+            os.environ['PYROCUMULUS_SETTINGS_MODULE'] = self.settings
+
 
 def get_command(name):
     """
@@ -136,5 +151,36 @@ def run_command():
     runs a pyrocumulus command based on the command line
     """
     command_name = get_command_name()
-    command = get_command(command_name)()
-    command.run()
+    if command_name == '--help' or command_name == '-h':
+        show_help_message()
+    else:
+        command = get_command(command_name)()
+        command.run()
+
+def show_help_message():  # pragma: no cover
+    """
+    Print a help message about command on screen and exit.
+    """
+
+    commands = list_commands()
+
+    msg = """
+Available commands:
+
+%s
+
+Use `python pyromanager.py cmd --help` for further information
+""" % '\n'.join(commands)
+
+    print(msg)
+
+def list_commands():
+    commands = []
+    commands_dir = resource_filename('pyrocumulus', 'commands')
+    for f in os.listdir(commands_dir):
+        if f.startswith('_') or not f.endswith('.py'):
+            continue
+        cmdname = f.split('.')[0]
+        if cmdname != 'base':
+            commands.append(cmdname)
+    return commands
