@@ -179,13 +179,8 @@ class RequestConverter(BaseConverter):
         get() or filter()
         """
 
-        # deform send some control keys which conflicts
-        # with mongoengine, so we remove it.
-        invalid_keys = ['_charset_', '__formid__']
         arguments = {}
         for key, value in self.obj.items():
-            if key in invalid_keys:
-                continue
 
             is_reference = self._is_reference(key)
             is_list = self._is_listfield(key)
@@ -214,10 +209,13 @@ class RequestConverter(BaseConverter):
             # called `thing`, let's try to get an
             # instance of the referenced object
             if is_reference:
-                key = key.split('_id')[0]
+                param_name = key.split('__')[1]
+                # key == refname
+                key = key.split('__')[0]
                 ref_class = self.parsed_model['reference_fields'][key]
                 try:
-                    value = ref_class.objects.get(id=value)
+                    kwargs = {param_name: value}
+                    value = ref_class.objects.get(**kwargs)
                 except ref_class.DoesNotExist:
                     value = None
 
@@ -240,7 +238,7 @@ class RequestConverter(BaseConverter):
         return is_date
 
     def _is_reference(self, key):
-        if key.endswith('_id') and key.split('_id')[0] \
+        if '__' in key and key.split('__')[0] \
            in self.parsed_model['reference_fields'].keys():
             return True
         return False
